<?php

namespace Litecms\Rating\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Rating\Models\Rating;

class RatingPolicy
{

    /**
     * Determine if the given user can view the rating.
     *
     * @param UserPolicy $user
     * @param Rating $rating
     *
     * @return bool
     */
    public function view(UserPolicy $user, Rating $rating)
    {
        if ($user->canDo('rating.rating.view') && $user->isAdmin()) {
            return true;
        }

        return $rating->user_id == user_id() && $rating->user_type == user_type();
    }

    /**
     * Determine if the given user can create a rating.
     *
     * @param UserPolicy $user
     * @param Rating $rating
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('rating.rating.create');
    }

    /**
     * Determine if the given user can update the given rating.
     *
     * @param UserPolicy $user
     * @param Rating $rating
     *
     * @return bool
     */
    public function update(UserPolicy $user, Rating $rating)
    {
        if ($user->canDo('rating.rating.edit') && $user->isAdmin()) {
            return true;
        }

        return $rating->user_id == user_id() && $rating->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given rating.
     *
     * @param UserPolicy $user
     * @param Rating $rating
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Rating $rating)
    {
        return $rating->user_id == user_id() && $rating->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given rating.
     *
     * @param UserPolicy $user
     * @param Rating $rating
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Rating $rating)
    {
        if ($user->canDo('rating.rating.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given rating.
     *
     * @param UserPolicy $user
     * @param Rating $rating
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Rating $rating)
    {
        if ($user->canDo('rating.rating.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
